/*
 Copyright 2014 Google Inc. All rights reserved.

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */

(function(window) {

	if (!!window.cookieChoices) {
		return window.cookieChoices;
	}

	var document = window.document;
	// IE8 does not support textContent, so we should fallback to innerText.
	var supportsTextContent = false;
	if( document.body.textContent ) supportsTextContent = true;

	var cookieChoices = (function() {

		// da cambiare a seconda del sito ...
		var pathArticoli = './';
		var pathImages = './images/';
		
		var cookieName = 'displayCookieConsent';
		// Id e Class
		var cookieConsentId = 'cookieChoiceInfo';
		var cookieConsentIdBody = 'cookieChoiceInfoBody';
		var dismissLinkId = 'cookieChoiceDismiss';
		var contentTitleClass = 'msgTitle';
		var contentTextClass = 'msgText';
		var glassPanelClass = 'glassPanel';
		var contentClass = 'contentChoice';
		var contentLinkClass = 'contentLink';
		var dialogClass = 'dialog';
		var toolbarActionsClass = 'toolbarActions';
		var bgColor = '#478B3D';
		var fontColorP = '#fff';
		var fontColorS = '#ccc';

		function _createHeaderElement(cookieTitle, cookieText, dismissText, linkText, linkHref) 
		{
			var cookieConsentElement = document.createElement('div');
			cookieConsentElement.id = cookieConsentId;
			var contentTitleElement = _createConsentText(cookieTitle);
			contentTitleElement.className = contentTitleClass;
			var imgDialog = document.createElement('img');
			imgDialog.src = pathImages + 'info.png';
			cookieConsentElement.appendChild(imgDialog);

			var cookieConsentBodyElement = document.createElement('div');
			cookieConsentBodyElement.id = cookieConsentIdBody;

			cookieConsentBodyElement.appendChild(contentTitleElement);
			cookieConsentBodyElement.appendChild(_createBr());
			cookieConsentBodyElement.appendChild(_createConsentText(cookieText));
			cookieConsentBodyElement.appendChild(_createBr());

			if (!!linkText && !!linkHref) {
				cookieConsentBodyElement.appendChild(_createInformationLink('Il Garante', 'http://www.garanteprivacy.it/web/guest/home/docweb/-/docweb-display/docweb/2142939'));
				cookieConsentBodyElement.appendChild(_createInformationLink(linkText, pathArticoli + linkHref));
			}
			var contentLinkElement = _createDismissLink(dismissText);
			contentLinkElement.className = contentLinkClass;
			cookieConsentBodyElement.appendChild(contentLinkElement);
			cookieConsentElement.appendChild(cookieConsentBodyElement);
			return cookieConsentElement;
		}

		function _setElementText(element, text) {
			if (supportsTextContent) {
				element.textContent = text;
			} else {
				element.innerText = text;
			}
		}

		function _createBr() {
			var consentText = document.createElement('br');
			return consentText;
		}

		function _createConsentText(cookieText) {
			var consentText = document.createElement('span');
			_setElementText(consentText, cookieText);
			return consentText;
		}

		function _createDismissLink(dismissText) {
			var dismissLink = document.createElement('a');
			_setElementText(dismissLink, dismissText);
			dismissLink.id = dismissLinkId;
			dismissLink.href = '#';
			return dismissLink;
		}

		function _createInformationLink(linkText, linkHref) {
			var infoLink = document.createElement('a');
			_setElementText(infoLink, linkText);
			infoLink.href = linkHref;
			infoLink.target = '_blank';
			return infoLink;
		}

		function _dismissLinkClick() {
			_saveUserPreference();
			_removeCookieConsent();
			return false;
		}

		function _showCookieConsent(cookieTitle, cookieText, dismissText, linkText, linkHref, isDialog) {
			if (_shouldDisplayConsent()) 
			{
				_removeCookieConsent();
				var consentElement = (isDialog) ?
				_createDialogElement(cookieTitle, cookieText, dismissText, linkText, linkHref):
				_createHeaderElement(cookieTitle, cookieText, dismissText, linkText, linkHref);
				var fragment = document.createDocumentFragment();
				fragment.appendChild(consentElement);
				document.body.insertBefore(fragment.cloneNode(true), document.body.firstChild);
				document.getElementById(dismissLinkId).onclick = _dismissLinkClick;
			}
		}

		function showCookieConsentBar(cookieTitle, cookieText, dismissText, linkText, linkHref) {
			_showCookieConsent(cookieTitle, cookieText, dismissText, linkText, linkHref, false);
		}

		function _removeCookieConsent() {
			var cookieChoiceElement = document.getElementById(cookieConsentId);
			if (cookieChoiceElement != null) {
				cookieChoiceElement.parentNode.removeChild(cookieChoiceElement);
			}
		}

		function _saveUserPreference() {
			// Set the cookie expiry to one year after today.
			var expiryDate = new Date();
			expiryDate.setFullYear(expiryDate.getFullYear() + 1);
			document.cookie = cookieName + '=y; expires=' + expiryDate.toGMTString();
		}

		function _shouldDisplayConsent() {
			// Display the header only if the cookie has not been set.
			return !document.cookie.match(new RegExp(cookieName + '=([^;]+)'));
		}

		var exports = {};
		exports.showCookieConsentBar = showCookieConsentBar;
		return exports;
	})();

	window.cookieChoices = cookieChoices;
	return cookieChoices;
})(this);

function addListener(obj, eventName, listener) {
	if(obj.addEventListener) {
		obj.addEventListener(eventName, listener, false);
	} else {
		obj.attachEvent("on" + eventName, listener);
	}
}

function onLoadDocument(event) {
	cookieChoices.showCookieConsentBar(
		'Ben venuti sul nostro sito.',
		'Continuando la navigazione del sito accetti i cookies di tipo "tecnico" necessari per la visualizzazione delle pagine.',
		'Chiudi ed Accetta', 
		'Informativa', 
		'informativa.html');
}
addListener(document,'DOMContentLoaded',onLoadDocument);
